@@ -20,7 +20,20 @@ import bottlenose
 from lxml import objectify, etree
 
 
-AMAZON_ASSOCIATES_BASE_URL = 'http://www.amazon.{region}/dp/'
+# https://kdp.amazon.com/help?topicId=A1CT8LK6UW2FXJ
+# CN not listed
+DOMAINS = {
+    'CA': 'ca',
+    'DE': 'de',
+    'ES': 'es',
+    'FR': 'fr',
+    'IT': 'it',
+    'JP': 'co.jp',
+    'UK': 'co.uk',
+    'US': 'com',
+}
+
+AMAZON_ASSOCIATES_BASE_URL = 'http://www.amazon.{domain}/dp/'
 
 
 class AmazonException(Exception):
@@ -92,7 +105,7 @@ class AmazonAPI(object):
             An instance of :class:`~.AmazonProduct` if one item was returned,
             or a list of  :class:`~.AmazonProduct` instances if multiple
             items where returned.
-        """
+        """ 
         response = self.api.ItemLookup(ResponseGroup=ResponseGroup, **kwargs)
         root = objectify.fromstring(response)
         if root.Items.Request.IsValid == 'False':
@@ -171,6 +184,8 @@ class AmazonAPI(object):
         :return:
             An :class:`~.AmazonSearch` iterable.
         """
+        region = kwargs.get('region', self.region)
+        kwargs.update({'region': region})
         return AmazonSearch(self.api, self.aws_associate_tag, **kwargs)
 
     def search_n(self, n, **kwargs):
@@ -181,6 +196,8 @@ class AmazonAPI(object):
         :return:
             A list of :class:`~.AmazonProduct`.
         """
+        region = kwargs.get('region', self.region)
+        kwargs.update({'region': region})
         items = AmazonSearch(self.api, self.aws_associate_tag, **kwargs)
         return list(islice(items, n))
 
@@ -216,7 +233,8 @@ class AmazonSearch(object):
         """
         for page in self.iterate_pages():
             for item in getattr(page.Items, 'Item', []):
-                yield AmazonProduct(item, self.aws_associate_tag, self.api)
+                yield AmazonProduct(
+                    item, self.aws_associate_tag, self.api, **self.kwargs)
 
     def iterate_pages(self):
         """Iterate Pages.
@@ -315,6 +333,19 @@ class AmazonBrowseNode(object):
             node = node.ancestor
         return ancestors
 
+    @property
+    def children(self):
+        """This browse node's children in the browse node tree.
+
+    :return:
+    A list of this browse node's children in the browse node tree.
+    """
+        children = []
+        child_nodes = getattr(self.element, 'Children')
+        for child in getattr(child_nodes, 'BrowseNode', []):
+                children.append(AmazonBrowseNode(child))
+        return children
+
 
 class AmazonProduct(object):
     """A wrapper class for an Amazon product.
@@ -330,13 +361,7 @@ class AmazonProduct(object):
         self.aws_associate_tag = aws_associate_tag
         self.api = api
         self.parent = None
-        if 'region' in kwargs:
-            if kwargs['region'] != "US":
-                self.region = kwargs['region']
-            else:
-                self.region = "com"
-        else:
-            self.region = "com"
+        self.region = kwargs.get('region', 'US')
 
     def to_string(self):
         """Convert Item XML to string.
@@ -451,6 +476,15 @@ class AmazonProduct(object):
         """
         return self._safe_get_element_text('ASIN')
 
+    @property
+    def sales_rank(self):
+        """Sales Rank
+
+        :return:
+            Sales Rank (integer).
+        """
+        return self._safe_get_element_text('SalesRank')
+
     @property
     def offer_url(self):
         """Offer URL
@@ -459,7 +493,7 @@ class AmazonProduct(object):
             Offer URL (string).
         """
         return "{0}{1}/?tag={2}".format(
-            AMAZON_ASSOCIATES_BASE_URL.format(region=self.region.lower()),
+            AMAZON_ASSOCIATES_BASE_URL.format(domain=DOMAINS[self.region]),
             self.asin,
             self.aws_associate_tag)
 
